/***************************************************************************
                          firststartdlg.h  -  description
                             -------------------
    begin                : Fre Jun 6 2003
    copyright            : (C) 2003 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef FIRSTSTARTDLG_H
#define FIRSTSTARTDLG_H

#include <tqwidget.h>
#include <kdialogbase.h>
#include "guimodeselector.h"

class FirstStartDlg : public KDialogBase, public GUIModeSelector {
    TQ_OBJECT
  
    public: 
        FirstStartDlg(TQWidget *parent=0, const char *name=0);
        ~FirstStartDlg();
};

#endif
